@@ -165,11 +165,8 @@ class PyWebHost(socketserver.ThreadingMixIn, socketserver.TCPServer,):
                 with selectors.SelectSelector() as selector:
                     selector.register(self, selectors.EVENT_READ)
                     while not self._BaseServer__shutdown_request:
-                        ready = selector.select(poll_interval)
-                        try:
-                            self.sched()
-                        except Exception:
-                            pass
+                        ready = selector.select(poll_interval)                        
+                        self.sched()
                         # bpo-35017: shutdown() called during select(), exit immediately.
                         if self._BaseServer__shutdown_request:
                             break
@@ -178,8 +175,7 @@ class PyWebHost(socketserver.ThreadingMixIn, socketserver.TCPServer,):
 
                         self.service_actions()
             finally:
-                self.__shutdown_request = False
-                self.__is_shut_down.set()
+                self._BaseServer__is_shut_down.set()
 
     def __handle__(self, request : RequestHandler):
         '''
